@@ -300,15 +300,11 @@ def close():
     """
     global logger, pid, process_name, inited, config, engine, conn, connected, levels, priorities, config_table, log_table, meta, log_fname, log_fhandle
     if conn: 
-        #Debug (4, "Closing DB connection")
         conn.close()
     if engine: 
-        #Debug (4, "Closing DB engine")
         engine.dispose()
-    #Debug (4, "Closing syslog connection")
     syslog.closelog()
     if (log_fhandle): 
-        #Debug (4, "Closing log file handle")
         log_fhandle.close()
     inited = False
 
@@ -333,7 +329,7 @@ def _log(level='DBG', message='', caller=None, debug_level=1):
     # If we are debug logging, show level too
     disp_level=level
     if level=='DBG':
-        disp_level = f'DBG{debug_level}'
+        disp_level = 'DBG{}'.format(debug_level)
     log_string = '{level} [{pname}] [{msg}]'.format(level=disp_level, pname=process_name, msg=message)
     # write to syslog
    
